@@ -1,4 +1,4 @@
-from sqlalchemy import Column, BIGINT, TEXT, INT, ForeignKey, UniqueConstraint, TIMESTAMP
+from sqlalchemy import Column, BIGINT, TEXT, INT, ForeignKey, UniqueConstraint, TIMESTAMP, JSON
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import relationship
 
@@ -8,12 +8,26 @@ Base = declarative_base()
 class Query(Base):
     def __init__(self):
         pass
+
+    def as_dict(self):
+        return {
+            'id': self.id,
+            'resource_id': self.resource_id,
+            'handle_pid': self.handle_pid,
+            'timestamp': str(self.timestamp),
+            'query': self.query,
+            'query_hash': self.query_hash,
+            'result_set_hash': self.result_set_hash,
+            'hash_algorithm': self.hash_algorithm,
+            'record_field_hash': self.record_field_hash
+        }
+
     __tablename__ = 'QUERY'
     id = Column(BIGINT, primary_key=True)
     resource_id = Column(TEXT)
     handle_pid = Column(TEXT)
     timestamp = Column(TIMESTAMP)
-    query = Column(TEXT)
+    query = Column(JSON)
     query_hash = Column(TEXT)
     result_set_hash = Column(TEXT)
     hash_algorithm = Column(TEXT)
