@@ -1,29 +1,10 @@
-import datetime
 import hashlib
 import json
-import urllib
 from collections import OrderedDict
-from json import JSONEncoder
-
-import dateutil
 
 HASH_ALGORITHM = hashlib.md5
 
 
-class DateTimeEncoder(JSONEncoder):
-    def default(self, obj):
-        if isinstance(obj, (datetime.date, datetime.datetime)):
-            return '[#convert_to_date]' + obj.isoformat()
-
-
-def decode_date_time(data):
-    if type(data) == dict:
-        for key in data.keys():
-            if type(data[key]) in (str, unicode) and data[key].startswith('[#convert_to_date]'):
-                data[key] = dateutil.parser.parse(data[key][18:])
-    return data
-
-
 def normalize_json(json_data, max_depth=3):
     ordered_dict = OrderedDict()
 
@@ -50,15 +31,15 @@ def calculate_hash(data):
     algo = HASH_ALGORITHM()
 
     if type(data) == str:
-        algo.update(data)
+        algo.update(data.encode('utf-8'))
     elif type(data) == dict:
-        algo.update(json.dumps(data, default=str, sort_keys=True))
+        algo.update(json.dumps(data, default=str, sort_keys=True, ensure_ascii=False).encode('utf-8'))
     elif type(data) == list:
         for doc in data:
-            algo.update(json.dumps(doc, default=str, sort_keys=True))
+            algo.update(json.dumps(doc, default=str, sort_keys=True, ensure_ascii=False).encode('utf-8'))
 
     return algo.hexdigest()
 
 
 def urlencode(s):
-    return urllib.parse.quote(s).replace('-', '--')
\ No newline at end of file
+    return s.replace('/','%2F').replace('-', '--')
